pub struct UncompressedTextures {
pub textures: Vec<UncompressedTexture>,
pub unk: [u32; 4],
}Fields
textures: Vec<UncompressedTexture>unk: [u32; 4]Trait Implementations
Sourceimpl BinRead for UncompressedTextures
impl BinRead for UncompressedTextures
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for UncompressedTextures
impl Clone for UncompressedTextures
Sourcefn clone(&self) -> UncompressedTextures
fn clone(&self) -> UncompressedTextures
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UncompressedTextures
impl Debug for UncompressedTextures
Sourceimpl PartialEq for UncompressedTextures
impl PartialEq for UncompressedTextures
Sourcefn eq(&self, other: &UncompressedTextures) -> bool
fn eq(&self, other: &UncompressedTextures) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Xc3Write for UncompressedTextures
impl Xc3Write for UncompressedTextures
Sourcetype Offsets<'offsets> = UncompressedTexturesOffsets<'offsets>
type Offsets<'offsets> = UncompressedTexturesOffsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types. Read more
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl StructuralPartialEq for UncompressedTextures