pub struct Unk4 {
pub unk1: u32,
pub unk2: Vec<Unk4Unk2>,
pub unk4: Option<Unk4Unk4>,
pub unk5: Option<Vec<Unk4Unk5>>,
pub unk6: u32,
pub unk7: Option<[[f32; 4]; 8]>,
pub extra: Option<Unk4Extra>,
pub unk: Option<[u32; 3]>,
pub buffer: Vec<u8>,
}Fields
unk1: u32unk2: Vec<Unk4Unk2>unk4: Option<Unk4Unk4>unk5: Option<Vec<Unk4Unk5>>unk6: u32unk7: Option<[[f32; 4]; 8]>extra: Option<Unk4Extra>unk: Option<[u32; 3]>buffer: Vec<u8>Trait Implementations
Sourceimpl BinRead for Unk4
impl BinRead for Unk4
Sourcetype Args<'__binrw_generated_args_lifetime> = Unk4BinReadArgs
type Args<'__binrw_generated_args_lifetime> = Unk4BinReadArgs
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Xc3Write for Unk4
impl Xc3Write for Unk4
Sourcetype Offsets<'offsets> = Unk4Offsets<'offsets>
type Offsets<'offsets> = Unk4Offsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types.
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl StructuralPartialEq for Unk4