Module map

Module map 

Map streaming data in .wismda files.

Many of these sections use the same formats as character models. .wismda files serve a similar purpose as .wismt files used for characters. Unlike the Msrd in most model .wismt files, .wismda files do not contain a header and can only be parsed by looking at the StreamEntry for the Msmd in the corresponding .wismhd file.

File Paths

GameFile Patterns
Xenoblade 1 DEmap/*.wismda
Xenoblade 2map/*.wismda
Xenoblade 3map/*.wismda
Xenoblade X DEmap/*.wismda

Modules

legacy
Legacy types for Xenoblade Chronicles X.

Structs

EnvModelData
The data for a EnvModel.
FoliageMaterial
FoliageMaterials
FoliageModelData
The data for a FoliageModel.
FoliageUnkData
FoliageVertex1
FoliageVertex2
FoliageVertexData
MapLowModelData
The data for a MapLowModel.
MapModelData
The data for a MapModel.
MapModelGroup
MapModelGroups
PropInstance
PropLod
PropLods
PropModelData
The data for a PropModel.
PropModelLod
PropPositionInfo
PropPositions
PropUnk3
RenderNode
Texture
TextureFlags