pub struct FoliageMaterials {
pub materials: Vec<FoliageMaterial>,
pub unk1: u32,
pub unk2: u32,
pub unk3: u32,
pub unk4: u32,
pub unk5: u32,
}Fields
materials: Vec<FoliageMaterial>unk1: u32unk2: u32unk3: u32unk4: u32unk5: u32Trait Implementations
Sourceimpl BinRead for FoliageMaterials
impl BinRead for FoliageMaterials
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for FoliageMaterials
impl Clone for FoliageMaterials
Sourcefn clone(&self) -> FoliageMaterials
fn clone(&self) -> FoliageMaterials
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FoliageMaterials
impl Debug for FoliageMaterials
Sourceimpl PartialEq for FoliageMaterials
impl PartialEq for FoliageMaterials
Sourcefn eq(&self, other: &FoliageMaterials) -> bool
fn eq(&self, other: &FoliageMaterials) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Xc3Write for FoliageMaterials
impl Xc3Write for FoliageMaterials
Sourcetype Offsets<'offsets> = FoliageMaterialsOffsets<'offsets>
type Offsets<'offsets> = FoliageMaterialsOffsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types. Read more
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl StructuralPartialEq for FoliageMaterials