pub struct BoundingBox {
pub max: [f32; 3],
pub min: [f32; 3],
pub center: [f32; 3],
}Fields
max: [f32; 3]min: [f32; 3]center: [f32; 3]Trait Implementations
Sourceimpl BinRead for BoundingBox
impl BinRead for BoundingBox
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for BoundingBox
impl Clone for BoundingBox
Sourcefn clone(&self) -> BoundingBox
fn clone(&self) -> BoundingBox
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundingBox
impl Debug for BoundingBox
Sourceimpl PartialEq for BoundingBox
impl PartialEq for BoundingBox
Sourcefn eq(&self, other: &BoundingBox) -> bool
fn eq(&self, other: &BoundingBox) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Xc3Write for BoundingBox
impl Xc3Write for BoundingBox
Sourcetype Offsets<'offsets> = BoundingBoxOffsets<'offsets>
type Offsets<'offsets> = BoundingBoxOffsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types. Read more
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl StructuralPartialEq for BoundingBox