pub struct MaterialVariable {
pub var_type: u8,
pub param: u8,
pub work_value_index: u16,
}Fields
var_type: u8param: u8work_value_index: u16Trait Implementations
Sourceimpl BinRead for MaterialVariable
impl BinRead for MaterialVariable
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for MaterialVariable
impl Clone for MaterialVariable
Sourcefn clone(&self) -> MaterialVariable
fn clone(&self) -> MaterialVariable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaterialVariable
impl Debug for MaterialVariable
Sourceimpl PartialEq for MaterialVariable
impl PartialEq for MaterialVariable
Sourcefn eq(&self, other: &MaterialVariable) -> bool
fn eq(&self, other: &MaterialVariable) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Xc3Write for MaterialVariable
impl Xc3Write for MaterialVariable
Sourcetype Offsets<'offsets> = MaterialVariableOffsets<'offsets>
type Offsets<'offsets> = MaterialVariableOffsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types. Read more
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl StructuralPartialEq for MaterialVariable