pub struct VertexBufferDescriptor {
pub data_offset: u32,
pub vertex_count: u32,
pub vertex_size: u32,
pub attributes: Vec<VertexAttribute>,
pub unk1: u32,
pub unk2: u32,
pub unk3: u32,
}Fields
data_offset: u32The offset into buffer.
vertex_count: u32vertex_size: u32The size or stride of the vertex in bytes.
attributes: Vec<VertexAttribute>A tightly packed list of attributes for the data for this buffer.
unk1: u32unk2: u32unk3: u32Trait Implementations
Sourceimpl BinRead for VertexBufferDescriptor
impl BinRead for VertexBufferDescriptor
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Clone for VertexBufferDescriptor
impl Clone for VertexBufferDescriptor
Sourcefn clone(&self) -> VertexBufferDescriptor
fn clone(&self) -> VertexBufferDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VertexBufferDescriptor
impl Debug for VertexBufferDescriptor
Sourceimpl PartialEq for VertexBufferDescriptor
impl PartialEq for VertexBufferDescriptor
Sourcefn eq(&self, other: &VertexBufferDescriptor) -> bool
fn eq(&self, other: &VertexBufferDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Xc3Write for VertexBufferDescriptor
impl Xc3Write for VertexBufferDescriptor
Sourcetype Offsets<'offsets> = VertexBufferDescriptorOffsets<'offsets>
type Offsets<'offsets> = VertexBufferDescriptorOffsets<'offsets>
The type storing offset data to be used in Xc3WriteOffsets.
Sourcefn xc3_write<W: Write + Seek>(
&self,
writer: &mut W,
endian: Endian,
) -> Xc3Result<Self::Offsets<'_>>
fn xc3_write<W: Write + Seek>( &self, writer: &mut W, endian: Endian, ) -> Xc3Result<Self::Offsets<'_>>
Write all fields and placeholder offsets.
This should almost always be derived for non primitive types. Read more
Sourcefn should_write(&self) -> Option<bool>
fn should_write(&self) -> Option<bool>
Return
Some(_) if the offset should be updated and
Some(true) if the data should also be written.
Defaults to Some(true).impl Eq for VertexBufferDescriptor
impl StructuralPartialEq for VertexBufferDescriptor